class Node:
    def __init__(self, start, end, X) -> None:
        self.start, self.end = start, end
        self.total = self.count = 0
        self._left = self._right = None
        self.X = X

    @property
    def mid(self):
        return (self.start + self.end) // 2

    @property
    def left(self):
        self._left = self._left or Node(self.start, self.mid, self.X)
        return self._left

    @property
    def right(self):
        self._right = self._right or Node(self.mid, self.end, self.X)
        return self._right

    def update(self, i: int, j: int, val: int) -> int:
        if i >= j: return 0
        if self.start == i and self.end == j:
            self.count += val
        else:
            self.left.update(i, min(self.mid, j), val)
            self.right.update(max(self.mid, i), j, val)

        if self.count > 0:
            self.total = self.X[self.end] - self.X[self.start]
        else:
            self.total = self.left.total + self.right.total

        return self.total

def area(rectangles):
    OPEN, CLOSE = 1, -1
    events = []
    
    X = set()
    for x1, y1, x2, y2 in rectangles:
        if (x1 < x2) and (y1 < y2):
            events.append((y1, OPEN, x1, x2))
            events.append((y2, CLOSE, x1, x2))
            X.add(x1)
            X.add(x2)
    events.sort()

    X = sorted(X)
    x_index = {x: i for i, x in enumerate(X)}
    active = Node(0, len(X) - 1, X)
    ans = 0
    cur_x_sum = 0
    cur_y = events[0][0]

    for y, typ, x1, x2 in events:
        ans += cur_x_sum * (y - cur_y)
        cur_x_sum = active.update(x_index[x1], x_index[x2], typ)
        cur_y = y

    return ans % (10**9 + 7)


# Do not modify below this line
if __name__ == '__main__':
    tests = int(input().strip())
    for test in range(tests):
      n = int(input().strip())
      rectList = []
      for _ in range(n):
        currRect = input().strip().split(' ')
        newRect = []
        for pos in currRect:
          newRect.append(int(pos))
        rectList.append(newRect)
      print(area(rectList))
